Crate blackrock2

A port of the Blackrock2 cipher used in Masscan to Rust.

Its original purpose is efficiently randomizing the order of port scans without having to put every possible target in memory and shuffling.

Original code.

Examples

use blackrock2::BlackRockIpGenerator;
 
for ip in BlackRockIpGenerator::new() {
    println!("{ip}")
}

Modules

generator

Structs

BlackRockIpGenerator
BlackRockIter